Learn R Programming

bnstruct (version 1.0)

jt.cliques: get the list of cliques of the junction tree of an InferenceEngine.

Description

Return the list of cliques containing the variables associated to each node of a junction tree.

Usage

jt.cliques(x)
"jt.cliques"(x)

Arguments

Value

the list of cliques of the junction tree contained in the InferenceEngine.