Learn R Programming

bnstruct (version 1.0)

marginals: compute the list of inferred marginals of a BN.

Description

Given an InferenceEngine, it returns a list containing the marginals for the variables in the network, according to the propagated beliefs.

Usage

marginals(x, ...)
"marginals"(x, ...)

Arguments

...
potential further arguments of methods.

Value

a list containing the marginals of each variable, as probability tables.

Examples

Run this code
## Not run: 
# eng <- InferenceEngine(net)
# marginals(eng)
# ## End(Not run)

Run the code above in your browser using DataLab