tune.knn.impute: tune the parameter k of the knn algorithm used in imputation.
Description
tune the parameter k of the knn algorithm used in imputation.
Usage
tune.knn.impute(data, cat.var = 1:ncol(data), k.min = 1, k.max = 20, frac.miss = 0.1, n.iter = 20, seed = 0)
Arguments
cat.var
vector containing the categorical variables
frac.miss
fraction of missing values to add
n.iter
number of iterations for each k
Value
matrix of error distributions