jt.cliques<-: set the list of cliques of the junction tree of an InferenceEngine.
Description
Add to the InferenceEngine a list containing the cliques of variables composing the nodes of the junction tree.
Usage
jt.cliques(x) <- value
"jt.cliques"(x) <- value